<?php

namespace Drp\IOEngage\Actions;

use Drp\IOEngage\DelegatesResults;
use Drp\IOEngage\Exceptions\NoContent;
use Drp\IOEngage\Facades\Token;
use Drp\IOEngage\Response;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\Http;

trait ManagesDelegates
{
    /**
     * @param string|array $identifiers
     */
    public function delegates($identifiers): DelegatesResults
    {
        $response = Http::withToken(Token::get()->accessToken)
            ->withHeaders(['x-ip-address' => config('ioengage.access_ip')])
            ->get($this->generateUrl($identifiers));

        try {
            $attributes = Response::handle($response);
        } catch (NoContent $exception) {
            $attributes = [
                'ValidRecordCount' => 0,
                'ValidResults' => [],
                'InvalidRecordCount' => 0,
                'InvalidResults' => [],
            ];
        }

        return new DelegatesResults($attributes);
    }

    /**
     * @param string|array $identifiers
     */
    private function generateUrl($identifiers): string
    {
        $identifiers = implode(',', Arr::wrap($identifiers));
        $url = config('ioengage.endpoints.delegate');

        return "{$url}/{$identifiers}?Country=GB";
    }
}
