<?php

namespace Drp\IOEngage\Actions;

use Drp\IOEngage\Exceptions\NoContent;
use Drp\IOEngage\Facades\Token;
use Drp\IOEngage\Response;
use Drp\IOEngage\SearchParameters;
use Drp\IOEngage\SearchResults;
use EventPortal\Contracts\SearchResults as SearchResultsContract;
use Illuminate\Support\Facades\Http;

trait ManagesSearch
{
    public function search(array $parameters, ?int $page = null, ?int $perPage = null): SearchResultsContract
    {
        $response = Http::withToken(Token::get()->accessToken)
            ->withHeaders(['x-ip-address' => config('ioengage.access_ip')])
            ->get(
                config('ioengage.endpoints.search'),
                SearchParameters::make($parameters, $page ?: 1, $perPage ?: 10)
            );

        try {
            $attributes = Response::handle($response);
        } catch (NoContent $exception) {
            $attributes = [
                'PerPage' => 0,
                'CurrentPage' => 0,
                'TotalPages' => 0,
                'TotalResults' => 0,
                'Results' => [],
            ];
        }

        return new SearchResults($attributes);
    }
}
