<?php

namespace Drp\IOEngage\Resources;

use Illuminate\Contracts\Support\Arrayable;
use Illuminate\Support\Arr;

class Delegate implements Arrayable
{
    /** @var string|null */
    public $identifier;

    /** @var string|null */
    public $title;

    /** @var string|null */
    public $firstName;

    /** @var string|null */
    public $lastName;

    /** @var string|null */
    public $gender;

    /** @var string|null */
    public $email;

    /** @var string|null */
    public $phone;

    /** @var string|null */
    public $jobTitle;

    /** @var string|null */
    public $suffix;

    /** @var string|null */
    public $salutation;

    /** @var string|null */
    public $company;

    /** @var bool */
    public $canBeMarketedTo = false;

    /** @var \Drp\IOEngage\Resources\Address|null */
    public $address;

    public function __construct(array $attributes)
    {
        $this->identifier = $this->getIdentifier($attributes);
        $this->title = Arr::get($attributes, 'PersonTitle');
        $this->firstName = Arr::get($attributes, 'FirstName');
        $this->lastName = Arr::get($attributes, 'LastName');
        $this->gender = Arr::get($attributes, 'Gender');
        $this->email = Arr::get($attributes, 'Email');
        $this->phone = Arr::get($attributes, 'Phone');
        $this->jobTitle = Arr::get($attributes, 'JobTitle');
        $this->suffix = Arr::get($attributes, 'Suffix');
        $this->salutation = Arr::get($attributes, 'Salutation');
        $this->company = Arr::get($attributes, 'Company');
        $this->canBeMarketedTo = (bool) $this->getCanBeMarketedTo($attributes);
        $this->address = Address::fromArray(Arr::get($attributes, 'Address', []));
    }

    public function toArray(): array
    {
        return [
            'identifier' => $this->identifier,
            'title' => $this->title,
            'first_name' => $this->firstName,
            'last_name' => $this->lastName,
            'gender' => $this->gender,
            'email' => $this->email,
            'phone' => $this->phone,
            'job_title' => $this->jobTitle,
            'suffix' => $this->suffix,
            'salutation' => $this->salutation,
            'company' => $this->company,
            'can_be_marketed_to' => $this->canBeMarketedTo,
            'address' => $this->address->toArray(),
        ];
    }

    private function getIdentifier(array $attributes): ?string
    {
        if (Arr::has($attributes, 'OneKeyId')) {
            return Arr::get($attributes, 'OneKeyId');
        }

        return Arr::get($attributes, 'OneKeyID');
    }

    private function getCanBeMarketedTo(array $attributes): ?string
    {
        if (Arr::has($attributes, 'CanbeMarketedTo')) {
            return Arr::get($attributes, 'CanbeMarketedTo');
        }

        return Arr::get($attributes, 'CanBeMarketedTo');
    }
}
