<?php

namespace Drp\IOEngage\Tests\Unit\Resources;

use Drp\IOEngage\Resources\Delegate;
use Drp\IOEngage\Tests\TestCase;

class DelegateTest extends TestCase
{
    /** @test **/
    public function can_be_constructed()
    {
        $delegate = new Delegate([
            'OneKeyId' => 'ONK23234',
            'PersonTitle' => 'Mr',
            'FirstName' => 'Dan',
            'LastName' => 'Jarrett',
            'Gender' => 'Male',
            'Email' => 'dan@example.com',
            'Phone' => '01234 56789',
            'JobTitle' => 'Javascript Developer',
            'Suffix' => 'PhD',
            'Salutation' => 'Sir',
            'Company' => 'drpg',
            'CanBeMarketedTo' => true,
            'Address' => [
                'Line1' => '212 Ikon Estate',
                'Line2' => 'Droitwich Road',
                'Line3' => 'Hartlebury',
                'City' => 'Kidderminster',
                'PostCode' => 'DY10 4EU',
                'County' => 'West Midlands',
                'Country' => 'United Kingdom',
            ]
        ]);

        $this->assertSame('ONK23234', $delegate->identifier);
        $this->assertSame('Mr', $delegate->title);
        $this->assertSame('Dan', $delegate->firstName);
        $this->assertSame('Jarrett', $delegate->lastName);
        $this->assertSame('Male', $delegate->gender);
        $this->assertSame('dan@example.com', $delegate->email);
        $this->assertSame('01234 56789', $delegate->phone);
        $this->assertSame('Javascript Developer', $delegate->jobTitle);
        $this->assertSame('PhD', $delegate->suffix);
        $this->assertSame('Sir', $delegate->salutation);
        $this->assertSame('drpg', $delegate->company);
        $this->assertSame(true, $delegate->canBeMarketedTo);
        $this->assertSame('212 Ikon Estate', $delegate->address->line1);
        $this->assertSame('Droitwich Road', $delegate->address->line2);
        $this->assertSame('Hartlebury', $delegate->address->line3);
        $this->assertSame('Kidderminster', $delegate->address->city);
        $this->assertSame('DY10 4EU', $delegate->address->areaCode);
        $this->assertSame('West Midlands', $delegate->address->area);
        $this->assertSame('United Kingdom', $delegate->address->country);
    }

    /** @test **/
    public function can_be_returned_as_array()
    {
        $delegate = new Delegate([
            'OneKeyId' => 'ONK23234',
            'PersonTitle' => 'Mr',
            'FirstName' => 'Dan',
            'LastName' => 'Jarrett',
            'Gender' => 'Male',
            'Email' => 'dan@example.com',
            'Phone' => '01234 56789',
            'JobTitle' => 'Javascript Developer',
            'Suffix' => 'PhD',
            'Salutation' => 'Sir',
            'Company' => 'drpg',
            'CanBeMarketedTo' => true,
            'Address' => [
                'Line1' => '212 Ikon Estate',
                'Line2' => 'Droitwich Road',
                'Line3' => 'Hartlebury',
                'City' => 'Kidderminster',
                'PostCode' => 'DY10 4EU',
                'County' => 'West Midlands',
                'Country' => 'United Kingdom',
            ]
        ]);

        $expected = [
            'identifier' => 'ONK23234',
            'title' => 'Mr',
            'first_name' => 'Dan',
            'last_name' => 'Jarrett',
            'gender' => 'Male',
            'email' => 'dan@example.com',
            'phone' => '01234 56789',
            'job_title' => 'Javascript Developer',
            'suffix' => 'PhD',
            'salutation' => 'Sir',
            'company' => 'drpg',
            'can_be_marketed_to' => true,
            'address' => [
                'line_1' => '212 Ikon Estate',
                'line_2' => 'Droitwich Road',
                'line_3' => 'Hartlebury',
                'city' => 'Kidderminster',
                'area_code' => 'DY10 4EU',
                'area' => 'West Midlands',
                'country' => 'United Kingdom',
            ]
        ];

        $this->assertSame($expected, $delegate->toArray());
    }
}
