<?php

namespace Drp\IOEngage\Tests\Unit;

use Drp\IOEngage\Exceptions\BadRequest;
use Drp\IOEngage\Exceptions\NoContent;
use Drp\IOEngage\Response;
use Drp\IOEngage\Tests\TestCase;
use Illuminate\Support\Facades\Http;

class ResponseTest extends TestCase
{
    /** @test **/
    public function can_handle_no_content()
    {
        $this->expectException(NoContent::class);

        Http::fake(function () {
            return Http::response(null, 204);
        });

        $response = Http::get('');

        Response::handle($response);
    }

    /** @test **/
    public function can_handle_bad_request()
    {
        $this->expectException(BadRequest::class);

        Http::fake(function () {
            return Http::response(null, 400);
        });

        $response = Http::get('');

        Response::handle($response);
    }

    /** @test **/
    public function can_handle_error()
    {
        $this->expectException(\Exception::class);

        Http::fake(function () {
            return Http::response('Broken', 500);
        });

        $response = Http::get('');

        Response::handle($response);
    }
}
