<?php

namespace Drp\IOEngage\Tests\Unit;

use Drp\IOEngage\Resources\Delegate;
use Drp\IOEngage\SearchResults;
use Drp\IOEngage\Tests\TestCase;
use Illuminate\Support\Collection;

class SearchResultsTest extends TestCase
{
    /** @test **/
    public function can_be_constructed()
    {
        $results = new SearchResults([
            'PerPage' => 10,
            'CurrentPage' => 1,
            'TotalPages' => 5,
            'TotalResults' => 50,
            'Results' => [
                [
                    'OneKeyId' => 'ONK23234',
                    'PersonTitle' => 'Mr',
                    'FirstName' => 'Dan',
                    'LastName' => 'Jarrett',
                    'Gender' => 'Male',
                    'Email' => 'dan@example.com',
                    'Phone' => '01234 56789',
                    'JobTitle' => 'Javascript Developer',
                    'Suffix' => 'PhD',
                    'Salutation' => 'Sir',
                    'Company' => 'drpg',
                    'CanBeMarketedTo' => true,
                    'Address' => [
                        'Line1' => '212 Ikon Estate',
                        'Line2' => 'Droitwich Road',
                        'Line3' => 'Hartlebury',
                        'City' => 'Kidderminster',
                        'PostCode' => 'DY10 4EU',
                        'County' => 'West Midlands',
                        'Country' => 'United Kingdom',
                    ],
                ],
            ],
        ]);

        $this->assertSame(10, $results->perPage);
        $this->assertSame(1, $results->currentPage);
        $this->assertSame(5, $results->totalPages);
        $this->assertSame(50, $results->totalResults);

        $this->assertCount(1, $results->delegates);
        $this->assertInstanceOf(Collection::class, $results->delegates);
        $this->assertInstanceOf(Delegate::class, $results->delegates->first());
    }

    /** @test **/
    public function can_be_returned_as_array()
    {
        $results = new SearchResults([
            'PerPage' => 10,
            'CurrentPage' => 1,
            'TotalPages' => 5,
            'TotalResults' => 50,
            'Results' => [
                [
                    'OneKeyId' => 'ONK23234',
                    'PersonTitle' => 'Mr',
                    'FirstName' => 'Dan',
                    'LastName' => 'Jarrett',
                    'Gender' => 'Male',
                    'Email' => 'dan@example.com',
                    'Phone' => '01234 56789',
                    'JobTitle' => 'Javascript Developer',
                    'Suffix' => 'PhD',
                    'Salutation' => 'Sir',
                    'Company' => 'drpg',
                    'CanBeMarketedTo' => true,
                    'Address' => [
                        'Line1' => '212 Ikon Estate',
                        'Line2' => 'Droitwich Road',
                        'Line3' => 'Hartlebury',
                        'City' => 'Kidderminster',
                        'PostCode' => 'DY10 4EU',
                        'County' => 'West Midlands',
                        'Country' => 'United Kingdom',
                    ],
                ],
            ],
        ]);

        $expected = [
            'per_page' => 10,
            'current_page' => 1,
            'total_pages' => 5,
            'total_results' => 50,
            'delegates' => [
                [
                    'identifier' => 'ONK23234',
                    'title' => 'Mr',
                    'first_name' => 'Dan',
                    'last_name' => 'Jarrett',
                    'gender' => 'Male',
                    'email' => 'dan@example.com',
                    'phone' => '01234 56789',
                    'job_title' => 'Javascript Developer',
                    'suffix' => 'PhD',
                    'salutation' => 'Sir',
                    'company' => 'drpg',
                    'can_be_marketed_to' => true,
                    'address' => [
                        'line_1' => '212 Ikon Estate',
                        'line_2' => 'Droitwich Road',
                        'line_3' => 'Hartlebury',
                        'city' => 'Kidderminster',
                        'area_code' => 'DY10 4EU',
                        'area' => 'West Midlands',
                        'country' => 'United Kingdom',
                    ],
                ],
            ],
        ];

        $this->assertSame($expected, $results->toArray());
    }
}
